package cc.mrlb.smartlink.smartlink_flutter;

import android.content.Context;

import androidx.annotation.NonNull;

import com.hiflying.smartlink.ISmartLinker;
import com.hiflying.smartlink.OnSmartLinkListener;
import com.hiflying.smartlink.SmartLinkedModule;
import com.hiflying.smartlink.v7.MulticastSmartLinker;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * SmartlinkFlutterPlugin
 */
public class SmartlinkFlutterPlugin implements FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private Context context;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "smartlink_flutter");
        channel.setMethodCallHandler(this);
        context = flutterPluginBinding.getApplicationContext();
    }

    protected ISmartLinker mSmartLinker;

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("stopLink")) {
            if(mSmartLinker!=null){
                mSmartLinker.stop();
            }
            result.success("true");
        } else if (call.method.equals("startLink")) {
            final String ssid = call.argument("ssid");
            final String password = call.argument("password");
            try {
                mSmartLinker = MulticastSmartLinker.getInstance();
                mSmartLinker.setOnSmartLinkListener(new OnSmartLinkListener() {
                    @Override
                    public void onLinked(final SmartLinkedModule module) {
                        result.success(module.getMac());
                    }

                    @Override
                    public void onCompleted() {
                    }

                    @Override
                    public void onTimeOut() {
                        result.error("TIMEOUT", "超时,未成功,请检查wifi帐号密码是否正确", null);
                    }
                });
                //开始 smartLink
                mSmartLinker.start(context, password.trim(), ssid.trim());
            } catch (Exception e) {
                // TODO Auto-generated catch block
                e.printStackTrace();
                result.error("SDKERROR", "连接wifi时出现异常", null);
            }

        } else {
            result.notImplemented();
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }
}
